svn commit: samba r24396 - in branches/SAMBA_4_0/source/winbind: .

kai at samba.org kai at samba.org
Tue Aug 14 07:18:41 GMT 2007


Author: kai
Date: 2007-08-14 07:18:41 +0000 (Tue, 14 Aug 2007)
New Revision: 24396

WebSVN: http://websvn.samba.org/cgi-bin/viewcvs.cgi?view=rev&root=samba&rev=24396

Log:
Fix a typo.

Thanks to metze (metze at samba.org) for catching this one.

Modified:
   branches/SAMBA_4_0/source/winbind/wb_gid2sid.c


Changeset:
Modified: branches/SAMBA_4_0/source/winbind/wb_gid2sid.c
===================================================================
--- branches/SAMBA_4_0/source/winbind/wb_gid2sid.c	2007-08-14 07:15:16 UTC (rev 24395)
+++ branches/SAMBA_4_0/source/winbind/wb_gid2sid.c	2007-08-14 07:18:41 UTC (rev 24396)
@@ -33,7 +33,7 @@
 };
 
 struct composite_context *wb_gid2sid_send(TALLOC_CTX *mem_ctx,
-		struct wbsrv_service *service, uid_t uid)
+		struct wbsrv_service *service, gid_t gid)
 {
 	struct composite_context *result;
 	struct gid2sid_state *state;
@@ -51,8 +51,8 @@
 	state->service = service;
 
 	/* FIXME: This is a stub so far.
-	 * We cheat by just using the uid as RID with the domain SID.*/
-	state->sid = dom_sid_add_rid(result, service->primary_sid, uid);
+	 * We cheat by just using the gid as RID with the domain SID.*/
+	state->sid = dom_sid_add_rid(result, service->primary_sid, gid);
 	if (composite_nomem(state->sid, state->ctx)) return result;
 
 	composite_done(state->ctx);



More information about the samba-cvs mailing list